@@ -4,26 +4,19 @@ import os
 
 from tests.test_utils import run_track_tests
 
-from mirdata import gtzan_genre
-from tests.test_utils import DEFAULT_DATA_HOME
+from mirdata.datasets import gtzan_genre
 
-TEST_DATA_HOME = "tests/resources/mir_datasets/GTZAN-Genre"
-
-
-def test_track_default_data_home():
-    # test data home None
-    track_default = gtzan_genre.Track("country.00000")
-    assert track_default._data_home == os.path.join(DEFAULT_DATA_HOME, "GTZAN-Genre")
+TEST_DATA_HOME = "tests/resources/mir_datasets/gtzan_genre"
 
 
 def test_track():
     default_trackid = "country.00000"
     track = gtzan_genre.Track(default_trackid, data_home=TEST_DATA_HOME)
     expected_attributes = {
-        'genre': "country",
-        'audio_path': "tests/resources/mir_datasets/GTZAN-Genre/"
+        "genre": "country",
+        "audio_path": "tests/resources/mir_datasets/gtzan_genre/"
         + "gtzan_genre/genres/country/country.00000.wav",
-        'track_id': "country.00000",
+        "track_id": "country.00000",
     }
     run_track_tests(track, expected_attributes, {})
 
@@ -33,8 +26,8 @@ def test_track():
 
 
 def test_hiphop():
-    track = gtzan_genre.Track('hiphop.00000', data_home=TEST_DATA_HOME)
-    assert track.genre == 'hip-hop'
+    track = gtzan_genre.Track("hiphop.00000", data_home=TEST_DATA_HOME)
+    assert track.genre == "hip-hop"
 
 
 def test_to_jams():
